Learn R Programming

hhsmm (version 0.4.2)

cov.mix.wt: weighted covariance

Description

The weighted means and variances using the observation matrix and the estimated weight vectors

Usage

cov.mix.wt(
  x,
  wt1 = rep(1/nrow(x), nrow(x)),
  wt2 = rep(1/nrow(x), nrow(x)),
  cor = FALSE,
  center = TRUE,
  method = c("unbiased", "ML")
)

Value

list containing the following items:

  • center the weighted mean of x

  • cov the weighted covariance of x

  • n.obs the number of observations in x

  • cor the weighted correlation of x, if the parameter cor is TRUE

  • wt1 the state weighs wt1

  • wt2 the mixture component weights wt2

  • pmix the estimated mixture proportions

Arguments

x

the observation matrix

wt1

the state probabilities matrix (number of observations times number of states)

wt2

the mixture components probabilities list (of length nstate) of matrices (number of observations times number of mixture components)

cor

logical. if TRUE the weighted correlation is also given

center

logical. if TRUE the weighted mean is also given

method

with two possible entries:

  • "unbiased" the unbiased estimator is given

  • "ML" the maximum likelihood estimator is given

Author

Morteza Amini, morteza.amini@ut.ac.ir, Afarin Bayat, aftbayat@gmail.com

Examples

Run this code
data(CMAPSS)
n = nrow(CMAPSS$train$x)
wt1 = runif(n)
wt2 = runif(n)
cov.mix.wt(CMAPSS$train$x, wt1, wt2)

Run the code above in your browser using DataLab