powered by
A function to compute the maximum homogeneity of two state sequences.
homogeneity(state.seq1, state.seq2)
a vector of a length equal to the maximum number of states giving the maximum homogeneity ratios
first state sequence
second state sequence
Morteza Amini, morteza.amini@ut.ac.ir
state.seq1 = c(3, 3, 3, 1, 1, 2, 2, 2, 2) state.seq2 = c(2, 2, 2, 3, 3, 1, 1, 1, 1) homogeneity(state.seq1, state.seq2)
Run the code above in your browser using DataLab