Learn R Programming

hhsmm (version 0.4.2)

ltr_reg_clus: left to right linear regression clustering

Description

A left to right initial linear regression clustering method using the coefficient differences and Hotelling's T-squared test

Usage

ltr_reg_clus(Dat, k, resp.ind = 1)

Value

a (left to right) clustering vector

Arguments

Dat

a data matrix

k

number of clusters

resp.ind

the column indices of the response variables for the linear regression clustering approach. The default is 1, which means that the first column is the univariate response variable

Author

Morteza Amini, morteza.amini@ut.ac.ir