Learn R Programming

hhsmm (version 0.4.2)

miss_mixmvnorm_mstep: the M step function of the EM algorithm

Description

The M step function of the EM algorithm for the mixture of multivariate normals as the emission distribution with missing values using the observation matrix and the estimated weight vectors

Usage

miss_mixmvnorm_mstep(x, wt1, wt2, par)

Value

list of emission (mixture multivariate normal) parameters: (mu, sigma and mix.p)

Arguments

x

the observation matrix which can contain missing values (NA or NaN)

wt1

the state probabilities matrix (number of observations times number of states)

wt2

the mixture components probabilities list (of length nstate) of matrices (number of observations times number of mixture components)

par

the parameters of the model in the previous step of the EM algorithm. For initialization of the model when the data is initially imputed, par can be NULL

Author

Morteza Amini, morteza.amini@ut.ac.ir

Examples

Run this code
data(CMAPSS)
n = nrow(CMAPSS$train$x)
wt1 = matrix(runif(3*n),nrow=n,ncol=3)
wt2 = list()
for(j in 1:3) wt2[[j]] = matrix(runif(5*n),nrow=n,ncol=5)
emission = miss_mixmvnorm_mstep(CMAPSS$train$x, wt1, wt2, par=NULL)

Run the code above in your browser using DataLab