Learn R Programming

hhsmm (version 0.4.2)

mixmvnorm_mstep: the M step function of the EM algorithm

Description

The M step function of the EM algorithm for the mixture of multivariate normals as the emission distribution using the observation matrix and the estimated weight vectors

Usage

mixmvnorm_mstep(x, wt1, wt2)

Value

list of emission (mixture multivariate normal) parameters: (mu, sigma and mix.p)

Arguments

x

the observation matrix

wt1

the state probabilities matrix (number of observations times number of states)

wt2

the mixture components probabilities list (of length nstate) of matrices (number of observations times number of mixture components)

Author

Morteza Amini, morteza.amini@ut.ac.ir, Afarin Bayat, aftbayat@gmail.com

Examples

Run this code
data(CMAPSS)
n = nrow(CMAPSS$train$x)
wt1 = matrix(runif(3*n),nrow=n,ncol=3)
wt2 = list()
for(j in 1:3) wt2[[j]] = matrix(runif(5*n),nrow=n,ncol=5)
emission = mixmvnorm_mstep(CMAPSS$train$x, wt1, wt2)

Run the code above in your browser using DataLab