Learn R Programming

hhsmm (version 0.4.2)

rmixar: Random data generation from the mixture of Gaussian linear (Markov-switching) autoregressive models for hhsmm model

Description

Generates vectors of observations from mixture of Gaussian linear (Markov-switching) autoregressive model in a specified state and using the parameters of a specified model

Usage

rmixar(j, model, x)

Value

a random matrix of observations from mixture of Gaussian linear (Markov-switching) autoregressive model

Arguments

j

a specified state

model

a hhsmmspec model

x

the previous x vector as the covariate of the autoregressive model

Author

Morteza Amini, morteza.amini@ut.ac.ir