powered by
The weighted means and variances using the observation matrix and the estimated weight vectors
cov.mix.wt( x, wt1 = rep(1/nrow(x), nrow(x)), wt2 = rep(1/nrow(x), nrow(x)), cor = FALSE, center = TRUE, method = c("unbiased", "ML") )
list containing the following items:
center the weighted mean of x
center
x
cov the weighted covariance of x
cov
n.obs the number of observations in x
n.obs
cor the weighted correlation of x, if the parameter cor is TRUE
cor
wt1 the state weighs wt1
wt1
wt2 the mixture component weights wt2
wt2
pmix the estimated mixture proportions
pmix
the observation matrix
the state probabilities matrix (number of observations times number of states)
the mixture components probabilities list (of length nstate) of matrices (number of observations times number of mixture components)
logical. if TRUE the weighted correlation is also given
logical. if TRUE the weighted mean is also given
with two possible entries:
"unbiased" the unbiased estimator is given
"unbiased"
"ML" the maximum likelihood estimator is given
"ML"
Morteza Amini, morteza.amini@ut.ac.ir, Afarin Bayat, aftbayat@gmail.com
data(CMAPSS) n = nrow(CMAPSS$train$x) wt1 = runif(n) wt2 = runif(n) cov.mix.wt(CMAPSS$train$x, wt1, wt2)
Run the code above in your browser using DataLab