A left to right initial linear regression clustering method using the coefficient differences and Hotelling's T-squared test
ltr_reg_clus(Dat, k, resp.ind = 1)a (left to right) clustering vector
a data matrix
number of clusters
the column indices of the response variables for the linear regression clustering approach. The default is 1, which means that the first column is the univariate response variable
Morteza Amini, morteza.amini@ut.ac.ir