Generates vectors of observations from mixture of Gaussian linear (Markov-switching) autoregressive model in a specified state and using the parameters of a specified model
rmixar(j, model, x)a random matrix of observations from mixture of Gaussian linear (Markov-switching) autoregressive model
a specified state
a hhsmmspec model
the previous x vector as the covariate of the autoregressive model
Morteza Amini, morteza.amini@ut.ac.ir